function stat = MakeBlogPostFileLists(post_title,varargin)
%  function stat = MakeBlogPostFileLists(post_title)
%  make file lists for a blog post
%  inputs:
%    post_title: the post title as string e.g. 'P36SSNRimages'
%    blogdir: (optional = [mycodedisk ':\Projects\Blog\Posts\' ]) root dir of blog posts
%    mycodedisk: (optional = 'L') disk letter for my matlab files. 
%       used to exclude matlab utilities from list of files for code. 
%       assumes code I wrote is in separate disk. If this is not the case
%       you will have to modify code at line 43 so you can determine your files
%  outputs:
%    makes filelist of Matlab functions used in blog post directory
%    stat: debugging output (see code)
%  REA 15/Apr/2013 9:44
%  COPYRIGHT:  Robert E. Alvarez, 2013. All rights reserved.

nreqargs = 1;
if(nargin<nreqargs), error('%d args required, only have %d',nreqargs,nargin);end

mycodedisk = 'L';
blogdir = [mycodedisk ':\Projects\Blog\Posts\'] ;
if(nargin>nreqargs)
  i=1;
  while(i<=size(varargin,2))
     switch lower(varargin{i})
     case 'blogdir';          blogdir = varargin{i+1};  assert(ischar(blogdir));   i=i+1;
     case 'mycodedisk';          mycodedisk = varargin{i+1};  assert(ischar(mycodedisk));   i=i+1;
    otherwise
      error('Unknown argument %s given',varargin{i});
     end
     i=i+1;
  end
end

if blogdir(end) ~= filesep
   blogdir(end+1) = filesep;
end
dirname = [blogdir post_title filesep];

    % make list of files used in the post .m file

[list, builtins, classes] = depfun([dirname 'code' filesep post_title '.m']);
  % parse the list for my files and print out a list
s1 = regexpi(list,['[' mycodedisk ']:' ]); % my files in these disks
fid = fopen([dirname 'filelist.txt'],'w');
assert(fid ~= (-1));
for k = 1:length(s1)
    if s1{k} == 1
       fprintf(fid,'%s\n',regexprep(list{k}, '\\', '\\\\'));
    end
end
fclose(fid);


